<?php

declare(strict_types=1);

namespace Drupal\lms_certificate\Hook;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lms_certificate\BundleFieldDefinition;

/**
 * Hook implementations.
 */
class LmsCertificateHooks {

  /**
   * Implements hook_entity_field_storage_info().
   */
  #[Hook('entity_field_storage_info')]
  public function entityFieldStorageInfo(EntityTypeInterface $entity_type): array {
    $fields = [];
    if ($entity_type->id() === 'group') {
      $fields['certificate'] = BundleFieldDefinition::create('dynamic_entity_reference')
        ->setTargetEntityTypeId('group')
        ->setLabel(new TranslatableMarkup('Certificate'))
        ->setName('membership_group')
        ->setDescription(new TranslatableMarkup('Reference to an entity providing a certificate'));
    }
    return $fields;
  }

  /**
   * Implements hook_entity_bundle_field_info().
   */
  #[Hook('entity_bundle_field_info')]
  public function entityBundleFieldInfo(EntityTypeInterface $entity_type, string $bundle): array {
    $fields = [];
    if ($bundle === 'lms_course' && $entity_type->id() === 'group') {
      $fields['certificate'] = BundleFieldDefinition::create('dynamic_entity_reference')
        ->setTargetEntityTypeId('group')
        ->setDisplayConfigurable('form', TRUE)
        ->setLabel(new TranslatableMarkup('Certificate'))
        ->setDescription(new TranslatableMarkup('Reference to an entity providing a certificate'))
        ->setSetting('exclude_entity_types', FALSE)
        ->setSetting('entity_type_ids', []);
    }
    return $fields;
  }

}
